==> pegasus-merchandise-api-1.4.25-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpSpvCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.util.List;

/**  
 * @Author: LK【kai.li@thebeastshop.com】
 * @Date: 2016/9/26 14:54
 */
public class OpSpvCond extends BaseQueryCond implements Serializable {

    /**
     * 产品ID
     */
    private Long productId;

    /**
     * sku编码
     */
    private List<String> skuCodes;

    /**
     * 产品编码
     */
    private List<String> prodCodes;

    /**
     * 是否关联SKU
     */
    private Boolean withSku = false;

    private Boolean withSkuCombination = false;

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public List<String> getSkuCodes() {
        return skuCodes;
    }

    public void setSkuCodes(List<String> skuCodes) {
        this.skuCodes = skuCodes;
    }

    public List<String> getProdCodes() {
        return prodCodes;
    }

    public void setProdCodes(List<String> prodCodes) {
        this.prodCodes = prodCodes;
    }

    public Boolean isWithSku() {
        return withSku == null ? false : withSku;
    }

    public void setWithSku(Boolean withSku) {
        this.withSku = withSku;
    }

    public Boolean getWithSkuCombination() {
        return withSkuCombination;
    }

    public void setWithSkuCombination(Boolean withSkuCombination) {
        this.withSkuCombination = withSkuCombination;
    }
}

==> pegasus-merchandise-api-3.0.1-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpSpvCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;


import com.thebeastshop.common.BaseQueryCond;

import java.io.Serializable;
import java.util.List;

/**  
 * @Author: LK【kai.li@thebeastshop.com】
 * @Date: 2016/9/26 14:54
 */
public class OpSpvCond extends BaseQueryCond implements Serializable {

    /**
     * 产品ID
     */
    private Long productId;

    /**
     * sku编码
     */
    private List<String> skuCodes;

    /**
     * 产品编码
     */
    private List<String> prodCodes;

    /**
     * 是否关联SKU
     */
    private Boolean withSku = false;

    private Boolean withSkuCombination = false;

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public List<String> getSkuCodes() {
        return skuCodes;
    }

    public void setSkuCodes(List<String> skuCodes) {
        this.skuCodes = skuCodes;
    }

    public List<String> getProdCodes() {
        return prodCodes;
    }

    public void setProdCodes(List<String> prodCodes) {
        this.prodCodes = prodCodes;
    }

    public Boolean isWithSku() {
        return withSku == null ? false : withSku;
    }

    public void setWithSku(Boolean withSku) {
        this.withSku = withSku;
    }

    public Boolean getWithSkuCombination() {
        return withSkuCombination;
    }

    public void setWithSkuCombination(Boolean withSkuCombination) {
        this.withSkuCombination = withSkuCombination;
    }
}
